@@ -1,6 +1,6 @@
 /*
  * LibSylph -- E-Mail client library
- * Copyright (C) 1999-2010 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2017 Hiroyuki Yamamoto
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -95,6 +95,22 @@ gint syl_link	(const gchar	*src,
   #define HAVE_U32_TYPEDEF
 #endif
 
+#if defined(G_OS_WIN32) && !defined(_WIN64) && defined(HAVE_64BIT_TIME_T)
+  /* for backward binary compatibility. Use only in struct definition and
+     pointer arguments. */
+  typedef gint32 stime_t;
+#else
+  typedef time_t stime_t;
+#endif
+
+#if !GLIB_CHECK_VERSION(2, 26, 0)
+#if (defined (_MSC_VER) || defined (__MINGW32__)) && !defined(_WIN64)
+  typedef struct _stat32 GStatBuf;
+#else
+  typedef struct stat GStatBuf;
+#endif
+#endif
+
 #ifndef BIG_ENDIAN_HOST
   #if (G_BYTE_ORDER == G_BIG_ENDIAN)
     #define BIG_ENDIAN_HOST 1
@@ -225,6 +241,9 @@ gchar *itos_buf			(gchar	     *nstr,
 gchar *itos			(gint	      n);
 gchar *utos_buf			(gchar	     *nstr,
 				 guint	      n);
+gchar *to_human_readable_buf	(gchar	     *buf,
+				 size_t	      bufsize,
+				 gint64	      size);
 gchar *to_human_readable	(gint64	      size);
 
 /* alternative string functions */
@@ -367,6 +386,10 @@ gchar **strsplit_csv			(const gchar	*str,
 					 gchar		 delim,
 					 gint		 max_tokens);
 
+gchar *strconcat_csv			(gchar		 delim,
+					 const gchar	*field1,
+					 ...) G_GNUC_MALLOC G_GNUC_NULL_TERMINATED;
+
 gchar *get_abbrev_newsgroup_name	(const gchar	*group,
 					 gint		 len);
 gchar *trim_string			(const gchar	*str,
@@ -450,6 +473,7 @@ gint copy_dir			(const gchar	*src,
 gint move_file			(const gchar	*src,
 				 const gchar	*dest,
 				 gboolean	 overwrite);
+
 gint append_file_part		(FILE		*fp,
 				 off_t		 offset,
 				 size_t		 length,
@@ -459,6 +483,9 @@ gint copy_file_part		(FILE		*fp,
 				 size_t		 length,
 				 const gchar	*dest);
 
+gint copy_file_stream		(FILE		*fp,
+				 FILE		*dest_fp);
+
 gchar *canonicalize_str		(const gchar	*str);
 gint canonicalize_file		(const gchar	*src,
 				 const gchar	*dest);
@@ -499,14 +526,19 @@ gint execute_print_file		(const gchar	*file);
 gchar *get_command_output	(const gchar	*cmdline);
 
 /* open URI with external browser */
-gint open_uri(const gchar *uri, const gchar *cmdline);
+gint open_uri			(const gchar	*uri,
+				 const gchar	*cmdline);
+
+/* play sound */
+gint play_sound			(const gchar	*file,
+				 gboolean	 async);
 
 /* time functions */
-time_t remote_tzoffset_sec	(const gchar	*zone);
-time_t tzoffset_sec		(time_t		*now);
+stime_t remote_tzoffset_sec	(const gchar	*zone);
+stime_t tzoffset_sec		(stime_t	*now);
 gchar *tzoffset_buf		(gchar		*buf,
-				 time_t		*now);
-gchar *tzoffset			(time_t		*now);
+				 stime_t	*now);
+gchar *tzoffset			(stime_t	*now);
 void get_rfc822_date		(gchar		*buf,
 				 gint		 len);
 
